#
# spec file for package libvmime
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wmime
%define lname	libwmime2
Version:        1.0.0
Release:        1.3
Summary:        Library for working with RFC 5322, MIME messages and IMAP/POP/SMTP
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/grommunio/wmime/

Source:         https://github.com/grommunio/wmime/releases/download/wmime-%version/wmime-%version.tar.zst
Source2:        https://github.com/grommunio/wmime/releases/download/wmime-%version/wmime-%version.tar.asc
Patch1:         nodate.patch
BuildRequires:  cmake >= 2.8.3
BuildRequires:  gcc-c++
%if 0%{?rhel} || 0%{?fedora_version}
BuildRequires:  gnutls-devel
%else
BuildRequires:  libgnutls-devel
%endif
%if !0%{?sle_version}
BuildRequires:  libgsasl-devel
%endif
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  zstd
%if 0%{?with_pdf}
BuildRequires:  ImageMagick
BuildRequires:  doxygen
BuildRequires:  inkscape
BuildRequires:  texlive-collection-fontsrecommended
BuildRequires:  texlive-latex
BuildRequires:  tex(courier.sty)
BuildRequires:  tex(fancyheadings.sty)
BuildRequires:  tex(pcrr7t.tfm)
BuildRequires:  tex(ucs.sty)
%endif

%description
VMime is a C++ class library for working with RFC5322 and
MIME-conforming messages (RFC2045–2049), as well as Internet
messaging services like IMAP, POP or SMTP.

VMime can parse, generate and modify messages, and also connect to
store and transport services to receive or send messages over the
Internet. The library offers features to build a mail client.

%package -n %lname
Summary:        Library for working with MIME messages and IMAP/POP/SMTP
Group:          System/Libraries

%description -n %lname
VMime is a C++ class library for working with RFC5322 and
MIME-conforming messages (RFC2045–2049), as well as Internet
messaging services like IMAP, POP or SMTP.

VMime can parse, generate and modify messages, and also connect to
store and transport services to receive or send messages over the
Internet. The library offers features to build a mail client.

%package devel
Summary:        Development files for vmime, an e-mail message library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Obsoletes:      libvmime-devel < 0.9.2+git204
Provides:       libvmime-devel = 0.9.2+git204

%description devel
VMime is a C++ class library for working with RFC5322 and
MIME-conforming messages (RFC2045–2049), as well as Internet
messaging services like IMAP, POP or SMTP.

This subpackage contains the headers for the library's API.

%prep
%autosetup -p1

%build
%if 0%{?with_pdf}
pushd doc/book/
make book_pdf
popd
%endif

%cmake \
        -DCMAKE_INSTALL_PREFIX:PATH="%_prefix" \
        -DINCLUDE_INSTALL_DIR:PATH="%_includedir" \
        -DSYSCONF_INSTALL_DIR:PATH="%_sysconfdir" \
        -DSHARE_INSTALL_PREFIX:PATH="%_datadir" \
        -DCMAKE_INSTALL_LIBDIR:PATH="%_libdir" \
	-DVMIME_SENDMAIL_PATH:STRING="%_sbindir/sendmail" \
	-DVMIME_BUILD_SAMPLES:BOOL=OFF \
%if 0%{?sle_version}
	-DVMIME_HAVE_SASL_SUPPORT:BOOL=OFF \
%endif
	-DVMIME_HAVE_TLS_SUPPORT:BOOL=ON \
	-DVMIME_BUILD_STATIC_LIBRARY:BOOL=OFF \
	-DCMAKE_BUILD_TYPE:STRING="RelWithDebInfo" \
	-DCMAKE_CXX_FLAGS_RELWITHDEBINFO:STRING="%optflags" \
	-DCMAKE_CXX_FLAGS:STRING="%optflags" \
	-DCMAKE_C_FLAGS_RELWITHDEBINFO:STRING="%optflags" \
	-DCMAKE_C_FLAGS:STRING="%optflags" \
	-DVMIME_BUILD_DOCUMENTATION:BOOL=OFF
%cmake_build

%install
b="%buildroot"
%if 0%{?with_pdf}
mkdir -p "$b/%_docdir/%name"
cp -a doc/book/book.pdf "$b/%_docdir/%name/"
%endif
%cmake_install
find "$b" -type f -name "*.la" -delete

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING
%_libdir/libwmime.so.2*

%files devel
%_includedir/vmime
%_libdir/libwmime.so
%_libdir/pkgconfig/*.pc
%_libdir/cmake/
%if 0%{?with_pdf}
%_docdir/%name
%endif

%changelog
* Tue Jan 21 2025 Jan Engelhardt <jengelh@inai.de>
- Switch upstream location from vmime to wmime
- Update to release 1.0.0
  * No further changes from last snapshot (0.9.2+git203)
- Drop libvmime-soname.diff (merged in 1.0.0)
- Rename libvmime-nodatetime.diff to nodate.patch
* Wed Jul 24 2024 Jan Engelhardt <jengelh@inai.de>
- Update libvmime-soname.diff to support out-of-tree cmake builds
* Wed Jun 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 0.9.2+git203 (43b262bd)
  * another potential multiplication overflows
  * build: upgrade to C++17 when ICU is used
  * Fix a test failure in testNewFromString and
    pathTest::testGenerate
* Tue May 21 2024 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 0.9.2+git196 (d296c2d)
  * vmime: prevent loss of a space when a multi-word mailbox name
    contains an umlaut
* Wed Apr 24 2024 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 0.9.2+git191 (d03ad5f0)
  * url: fix an off-by-one error in parsing hostnames
  * url: strip leading slash from url-path
  * Support FIPS under OpenSSL 3
* Sun Feb 25 2024 Jan Engelhardt <jengelh@inai.de>
- Reinstate %%optflags
* Sun Dec 31 2023 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 0.9.2+git188 (c3c6242ed)
  * Fix emission of bugs Envelope-From to sendmail:// transports.
  * Add parsing feedback via parsingContext
- Drop 0001-Avoid-generating-illegal-Envelope-From-with-sendmail.patch
  (merged)
* Mon Dec 18 2023 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Avoid-generating-illegal-Envelope-From-with-sendmail.patch
* Sun Sep 25 2022 Jan Engelhardt <jengelh@inai.de>
- Force-add -fPIC under RHEL and derivatives
* Sat Jun 11 2022 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 0.9.2.175 (fc69321d)
  * Added utility function to convert byteArray to HEX string.
  * Added support for digest algorithm SHA256 (in certificates).
* Sat Jan  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add BuildRequires for RH/CentOS
* Sat Dec  4 2021 Jan Engelhardt <jengelh@inai.de>
- Wrap a number of build dependencies into %%{?with_pdf}
* Wed Nov 24 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 0.9.2.165 (edcb4b4b1f1f)
  * imap: Added support for pipelined and out-of-order replies.
  * smtp: Add basic support for delivery status notifications (DSN)
  * mime: Reply-To is now an addressList in accordance with the RFC
    (API change)
- Add libvmime-soname.diff
* Sun Oct  6 2019 Jan Engelhardt <jengelh@inai.de>
- Update to 0.9.2k4 (0.9.2.96)
  * Skip delimiter lines that are not exactly equal to the boundary
* Tue May 28 2019 Jan Engelhardt <jengelh@inai.de>
- Update to Kopano branch of vmime, 0.9.2k2 (0.9.2.85)
  * Unbreak own hostname qualification on POSIX systems
* Mon Jun 25 2018 jengelh@inai.de
- Update to new git snapshot v0.9.2-50-ga9b8221
  * Dropped support for boost::shared_ptr<>, enabled exclusive
    C++11 use of std::shared_ptr.
  * Handle parsing of (RFC-nonconforming) address lines containing
    bare at signs, like "a@b.c <e@f.g>" or
    "=?UTF-8?Q?a=c2=a0recipient_=28foo@bar.com=29?= <e@f.g>".
  * Add SMTPS with AUTH PLAIN without SASL.
* Mon Apr 23 2018 jengelh@inai.de
- Add no-override-cflags.diff so that vmime becomes externally
  buildable with other -O/-g levels.
* Thu Jul 13 2017 jengelh@inai.de
- Update description
* Thu Jul 13 2017 olaf@aepfle.de
- Remove openssl because gnutls is preferd already
* Wed Mar  8 2017 bosim@opensuse.org
- Don't stop the build due to SLES missing GSASL.
* Mon Jan 23 2017 jengelh@inai.de
- Resolve wrong name of cmake variable:
  CMAKE_RELEASE_TYPE -> CMAKE_BUILD_TYPE
* Tue Jan  3 2017 jengelh@inai.de
- Update to final release 0.9.2
  * Always ignore newlines between words.
- Drop dont-fixup.diff (issue fixed upstream),
  drop libvmime-sotag.diff (no longer needed).
* Sun Oct 30 2016 jengelh@inai.de
- Update to new git snapshot
  047cacb1dba516ca902b36a290f2b81555658c1e [0.9.2~g500]
  * Skip multiple (bogus) colons after header field name
- Add dont-fixup.diff
* Wed Jun 22 2016 jengelh@inai.de
- Update to new git snapshot
  4d1a6ad2f267e3b83f7c04122af8d8e7ee9a2113 [0.9.2~g490]
  * handle "x-uuencode" type
  * Skip word on unexpected error when fixing broken words.
  * XOAUTH2 auth mechanism support
* Wed May 13 2015 jengelh@inai.de
- Ship COPYING file
* Mon Aug 25 2014 dap@open.by, jengelh@inai.de
- Update to new git snapshot
  30ea54f269efa673a1eb5bc07e71715b67607dbc
  * No upstream changelog was provided
- Turn on SASL, TLS support
- Remove vmime-0.9.2-header-value-on-next-line.diff
  (no longer applies)
* Thu Dec 19 2013 jengelh@inai.de
- Use existing postscript fonts as BuildRequires
  (suggestion by user WernerFink)
* Mon Aug  5 2013 ro@suse.de
- BuildRequire texlive-bin-latex only for <= 12.3
* Wed Mar 27 2013 jengelh@inai.de
- Update to new git snapshot (54b5fe13f7e7cb6c4f63884e91ff472b42b63147)
- Removed because merged: vmime-0.8.1-charset-catch.diff,
  vmime-mixed-qp-in-parameter.diff, vmime-0.9.2-qp-in-buffers.diff
- Removed because they no longer apply: vmime-automake1_13.diff,
  vmime-noansiflag.patch
* Sun Mar  3 2013 jengelh@inai.de
- Add vmime-automake1_13.diff to fix up ancient autotools constructs
* Sat Aug 11 2012 jengelh@inai.de
- Make the package build on RHEL6
* Thu Jul 12 2012 jengelh@inai.de
- Enable always generating 7-bit parameters
  (https://jira.zarafa.com/browse/ZCP-9475)
* Thu May 10 2012 crrodriguez@opensuse.org
- Use RPM_OPT_FLAGS
- Do not use -ansi gcc flag.
* Fri Mar 16 2012 jengelh@medozas.de
- Update to new SVN snapshot rev 603 (ZCP 7.0.6 dependency)
  * Set Diffie-Hellman prime size (bug SF#3434852)
* Thu Jun 30 2011 jengelh@medozas.de
- Initial package for build.opensuse.org
